var VCall = function()
{
	var vcall = {};
	var debug = 0;
	
	var JOB_IMAGE = { 'DONE': 'ok.png', 'ERROR': 'error.png'};
	var rawBioAssays;
	
	// Page initialization
	vcall.initPage = function()
	{
		
		// Step 1

		// Navigation
		Buttons.addClickHandler('gocancel', Wizard.cancelWizard);
		Buttons.addClickHandler('gorestart', Wizard.restartWizard);
		Buttons.addClickHandler('gonext', Wizard.goNextOnClick);
		Buttons.addClickHandler('goregister', Wizard.goRegister);
			
		// Final registration
		Events.addEventHandler('wizard', 'wizard-submit', vcall.submit);

		Wizard.showLoadingAnimation('Loading bioassays...');
		var url = '../VariantCalling.servlet?ID='+App.getSessionId();
		url += '&cmd=GetUnconfirmed';
		Wizard.asyncJsonRequest(url, vcall.initializeStep1);
	}
	
	// --- Step 1 -----------------------------------
	vcall.initializeStep1 = function(response)
	{
		rawBioAssays = response.rawBioAssays;
		if (rawBioAssays.length == 0)
		{
			Wizard.setFatalError('No raw bioassays available for processing.');
			return;
		}
		
		var html = '<table id="rawBioAssaysTable">';
		html += '<thead class="bg-filled-100">';
		// Header row
		html += '<tr>';
		html += '<th></th>';
		html += '<th class="dottedleft"></th>';
		html += '<th class="dottedleft" colspan="5">Variant calling</th>'
		html += '<th class="dottedleft" colspan="3">Actions</th>';
		html += '<th class="dottedleft">Comment</th>';
		html += '</tr>';
		
		html += '<tr>';
		html += '<th>Library</th>';
		html += '<th class="dottedleft">Plate</th>';
		html += '<th class="dottedleft">Job</th>'
		html += '<th>Callable</th>';
		html += '<th>Raw</th>';
		html += '<th>Filtered</th>';
		html += '<th>Files</th>';
		html += '<th class="dottedleft">Flag RNA</th>';
		html += '<th>Re-run</th>';
		html += '<th>Confirm</th>';
		html += '<th class="dottedleft"></th>';
		html += '</tr>';
		html += '</thead>';
		html += '<tbody>';
		var numWithError = 0;
		var yellowImg = '<img src="../images/yellow-label.png">';
		for (var rawNo = 0; rawNo < rawBioAssays.length; rawNo++)
		{
			var raw = rawBioAssays[rawNo];

			var lib = raw.lib;
			lib.stratagene = Reggie.isStratagene(lib.name);
			lib.external = Reggie.isExternal(lib.name);
			var isYellow = lib.specimen && lib.specimen.YellowLabel != null;
			var img = isYellow ? yellowImg : '';
			var libPlate = lib.bioWell ? lib.bioWell.bioPlate : null;
			
			var vcallJob = raw.vcallJob;
			var isError = !raw.vcfFile || !raw.spots;
			var flagChecked = false;
	
			html += '<tr class="highlight ' + (rawNo % 4 < 2 ? 'evenrow' : 'oddrow') + (isYellow ? ' yellow-specimen' : '') + '">';
			html += '<td class="prompt if-yellow">'+img+Strings.encodeTags(raw.name)+'</td>';
			html += '<td class="dottedleft">'+(libPlate ? Strings.encodeTags(libPlate.name) : '-') +'</td>';

			html += '<td class="dottedleft">';
			if (vcallJob)
			{
				isError |= vcallJob.status == 'ERROR';
				var image = JOB_IMAGE[vcallJob.status];
				if (!isError && !raw.vcfFile) image = 'warning.png';
				html += '<span class="link item-link" data-item-type="JOB" data-item-id="'+vcallJob.id+'" title="'+Strings.encodeTags(vcallJob.statusMessage)+'"><img src="../images/'+image+'"></span>';
			}
			html += '</td>';
			html += '<td>'+Reggie.formatCount(raw.CallableBases)+'</td>';
			html += '<td>'+Reggie.formatCount(raw.VariantsRaw)+'</td>';
			html += '<td>';
			if (raw.vcfFile)
			{
				html += raw.spots + '<span class="link vcf-link" data-file-id="'+raw.vcfFile.id+'" data-item-id="'+raw.id+'" title="View summary for the variants"><img src="../images/vcf_file.png" style="margin-left: 2px;"></span>';
			}
			html += '</td>';

			if (raw.DataFilesFolder && vcallJob && vcallJob.server)
			{
				html += '<td>';
				html += '<span class="link file-link" data-server="'+Strings.encodeTags(vcallJob.server)+'" data-folder="'+Strings.encodeTags(raw.DataFilesFolder)+'" data-item-id="'+raw.id+'" title="View generated files"><img src="../images/remote_folder.png"></span>';
				html += '</td>';
			}
			else
			{
				html += '<td>-</td>';
			}
			// Do not allow flagging external or stratagene
			var confirmChecked = !isError ? ' checked' : '';
			var reRunChecked = isError ? ' checked' : '';
			var confirmDisabled = isError ? ' disabled' : '';
			if (isError) numWithError++;
			
			if (lib.stratagene || lib.external)
			{
				html += '<td class="dottedleft">-</td>';
			}
			else
			{
				html += '<td class="dottedleft"><input type="checkbox" name="flag.'+raw.id+'"'+(flagChecked ? ' checked':'')+'></td>';
			}
			
			html += '<td><input type="checkbox" name="rerun.'+raw.id+'"'+reRunChecked+'></td>';
			html += '<td><input type="checkbox" name="confirm.'+raw.id+'"'+confirmChecked+confirmDisabled+'></td>';
			html += '<td class="dottedleft comment"><input type="text" name="comment.'+raw.id+'"></td>';
			html += '</tr>';

		}
		html += '</tbody>';
		html += '</table>';
		Doc.element('rawBioAssays').innerHTML = html;
		
		// Add click handler to items
		var clickableItems = document.getElementsByClassName('item-link');
		for (var i = 0; i < clickableItems.length; i++)
		{
			Events.addEventHandler(clickableItems[i], 'click', Items.itemOnClick);
		}
		
		// Add click handler to file links
		var clickableItems = document.getElementsByClassName('file-link');
		for (var i = 0; i < clickableItems.length; i++)
		{
			Events.addEventHandler(clickableItems[i], 'click', vcall.fileLinkOnClick);
		}

		var linkedVcf = document.getElementsByClassName('vcf-link');
		for (var i = 0; i < linkedVcf.length; i++)
		{
			Events.addEventHandler(linkedVcf[i], 'click', vcall.vcfLinkOnClick);
		}

		
		Doc.show('step-1');
		Doc.show('goregister');
	}
	
	vcall.fileLinkOnClick = function(event)
	{
		var folder = Data.get(event.currentTarget, 'folder');
		var server = Data.get(event.currentTarget, 'server');
		var itemId = Data.get(event.currentTarget, 'item-id');
		server = server.replace(/\s*\[.*\]/, '');
		var url = 'view_remote_files.jsp?ID=' + App.getSessionId();
		url += '&clusterId='+server;
		url += '&path='+encodeURIComponent(folder);
		url += '&itemType=RAWBIOASSAY&itemId='+itemId;
		Dialogs.openPopup(url, 'ViewProjectFiles', 750, 500);
	}
	
	vcall.vcfLinkOnClick = function(event)
	{
		var fileId = Data.int(event.currentTarget, 'file-id');
		var itemId = Data.int(event.currentTarget, 'item-id');
		var url = 'view_variants.jsp?ID=' + App.getSessionId();
		url += '&fileId='+fileId;
		url += '&itemId='+itemId;
		Dialogs.openPopup(url, 'ViewVcf', 900, 600);
	}

	vcall.submit = function()
	{
		var frm = document.forms['reggie'];
		var submitInfo = {};
		submitInfo.deleteItemsCreatedByFailedJobs = frm.deleteItemsCreatedByFailedJobs.checked;
		
		var all = [];
		submitInfo.rawBioAssays = all;
		for (var rawNo = 0; rawNo < rawBioAssays.length; rawNo++)
		{
			var raw = rawBioAssays[rawNo];
			var tmp = {};
			tmp.id = raw.id;
			
			tmp.flag = frm['flag.'+raw.id] && frm['flag.'+raw.id].checked;
			tmp.rerun = frm['rerun.'+raw.id].checked;
			tmp.confirm = frm['confirm.'+raw.id].checked;
			tmp.comment = frm['comment.'+raw.id].value;
			
			all[all.length] = tmp;
		}
		
		var url = '../VariantCalling.servlet?ID='+App.getSessionId();
		url += '&cmd=ConfirmVariantCalling';
		Wizard.showLoadingAnimation('Performing registration...');
		Wizard.asyncJsonRequest(url, vcall.submissionResults, 'POST', JSON.stringify(submitInfo));
	}
	
	vcall.submissionResults = function(response)
	{
		Wizard.showFinalMessage(response.messages);
		Doc.show('gorestart');
	}
	
	
	return vcall;
}();

Doc.onLoad(VCall.initPage);

